Jan,
could you please also check in the below included header file
"plan_bundle.h" ?
Thanks!
Stefan
On Thu, May 07, 2009 at 08:00:19PM +0000, Jan Rittinger wrote:
Update of /cvsroot/monetdb/pathfinder/compiler/include
In directory 23jxhf1.ch3.sourceforge.com:/tmp/cvs-serv23317/include
Modified Files:
Makefile.ag logdebug.h properties.h xml2lalg.h
Log Message:
-- Extend Pathfinder (and the binaries pfopt and pfsql) to cope
with query plan bundles (generated by ferry). Multiple algebraic
plans bundled together form a query with a nested result type.
We can now import the XML representation of a query plan bundle
and optimize all plans in the bundle. Furthermore we can generate
a DOT, an XML, and a SQL representation of the query plan bundle.
NOTE: The XML import for 'normal' query plans as well as the code
and output generation still works as before.
U xml2lalg.h
Index: xml2lalg.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/xml2lalg.h,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- xml2lalg.h 8 Jan 2009 16:54:12 -0000 1.6
+++ xml2lalg.h 7 May 2009 20:00:16 -0000 1.7
@@ -39,6 +39,7 @@
#define XML2ALG_H
#include "logical.h"
+#include "plan_bundle.h"
#include "array.h"
@@ -53,10 +54,10 @@
XML2LALGContext*
PFxml2la_xml2lalgContext(void);
-PFla_op_t*
+PFla_pb_t*
PFxml2la_importXMLFromFile(XML2LALGContext* ctx, const char *filename);
-PFla_op_t*
+PFla_pb_t*
PFxml2la_importXMLFromMemory(XML2LALGContext* ctx, const char* xml, int size);
#endif
U logdebug.h
Index: properties.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/properties.h,v
retrieving revision 1.51
retrieving revision 1.52
diff -u -d -r1.51 -r1.52
--- properties.h 31 Jan 2009 00:01:15 -0000 1.51
+++ properties.h 7 May 2009 20:00:16 -0000 1.52
@@ -374,7 +374,7 @@
* Write domain-subdomain relationships of property container @a prop
* to in AT&T dot notation to character array @a f.
*/
-void PFprop_write_dom_rel_dot (PFarray_t *f, const PFprop_t *prop);
+void PFprop_write_dom_rel_dot (PFarray_t *f, const PFprop_t *prop, int id);
/**
* Write domain-subdomain relationships of property container @a prop
U Makefile.ag
Index: Makefile.ag
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/Makefile.ag,v
retrieving revision 1.52
retrieving revision 1.53
diff -u -d -r1.52 -r1.53
--- Makefile.ag 8 Jan 2009 16:54:12 -0000 1.52
+++ Makefile.ag 7 May 2009 20:00:16 -0000 1.53
@@ -82,6 +82,7 @@
physical.h \
physical_mnemonic.h \
planner.h \
+ plan_bundle.h \
prettyp.h \
properties.h \
qname.h \
------------------------------------------------------------------------------
The NEW KODAK i700 Series Scanners deliver under ANY circumstances! Your
production scanning environment may not be a perfect world - but thanks to
Kodak, there's a perfect scanner to get the job done! With the NEW KODAK i700
Series Scanner you'll get full speed at 300 dpi even with all image
processing features enabled. http://p.sf.net/sfu/kodak-com
_______________________________________________
Monetdb-pf-checkins mailing list
Monetdb-pf-checkins@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins
Index: logdebug.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/logdebug.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -d -r1.9 -r1.10
--- logdebug.h 8 Jan 2009 16:54:12 -0000 1.9
+++ logdebug.h 7 May 2009 20:00:16 -0000 1.10
@@ -4,7 +4,7 @@
* @file
*
* Declarations for logdebug.c; dump Algebra
* tree in AY&T dot format.
*
*
* Copyright Notice:
@@ -43,10 +43,15 @@
#include
#include "logical.h"
+#include "plan_bundle.h"
void PFla_dot (FILE *, PFla_op_t *, char *prop_args);
void PFla_xml (FILE *, PFla_op_t *, char *prop_args);
+/* Declaration for debug printing of plan bundles */
+void PFla_dot_bundle (FILE *, PFla_pb_t *, char *prop_args);
+void PFla_xml_bundle (FILE *, PFla_pb_t *, char *prop_args);
+
#endif /* LOGDEBUG_H */
/* vim:set shiftwidth=4 expandtab: */
U properties.h
@@ -4,7 +4,7 @@
*
* Declarations for logdebug.c; dump Algebra
- * tree in AY&T dot format.
+ * tree in AT&T dot or XML format.
*
*
--
| Dr. Stefan Manegold | mailto:Stefan.Manegold@cwi.nl |
| CWI, P.O.Box 94079 | http://www.cwi.nl/~manegold/ |
| 1090 GB Amsterdam | Tel.: +31 (20) 592-4212 |
| The Netherlands | Fax : +31 (20) 592-4312 |